%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%         DOCUMENT CLASS for seminars at the PST group
% 
% Authors:
%      Alexander Knapp, 2004
%      Annabelle Klarl, 2012
%      Marianne Busch,  2014
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% USAGE:
%
% \usepackage{seminarPST}
%
%    Commands for the options of the title page:
%       \author  % your name
%       \title   % the title of this thesis
%       \program % the title of the author's program
%       \seminar % the title of this seminar
%       \university % the name of the university
%
%    Commands for the creation of the title page:
%       \maketitle % creates the title page
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{seminarPST}[2014/12/09]

\LoadClass[a4paper,11pt,twoside,fleqn,leqno,tbtags]{amsart}

% Encoding: Allows the usage of umlauts
\RequirePackage[latin1]{inputenc}
% Allows the usage of images
\RequirePackage{graphicx}
% For mathematical symbols
\RequirePackage{amsmath,amssymb,amsthm}
% For special captions
\RequirePackage[format=plain,labelsep=colon,labelfont={normalfont,small,bf},font={small,sl},margin=.5cm, indention=.5cm]{caption} % for special captions
% For refs in the document
\RequirePackage{hyperref}

\DeclareOption*{%
  \PassOptionsToClass{\CurrentOption}{amsart}%
}

\ProcessOptions
\def\maketitle{\par
  \@topnum\z@ % this prevents figures from falling at the top of page 1
  \@setcopyright
  \thispagestyle{empty}% this sets first page specifications
  \uppercasenonmath\shorttitle
  \ifx\@empty\shortauthors \let\shortauthors\shorttitle
  \else \andify\shortauthors
  \fi
  \@maketitle@hook
  \begingroup
  \@maketitle
  \toks@\@xp{\shortauthors}\@temptokena\@xp{\shorttitle}%
  \toks4{\def\\{ \ignorespaces}}% defend against questionable usage
%  \edef\@tempa{%
%    \@nx\markboth{\the\toks4
%      \@nx\MakeUppercase{\the\toks@}}{\the\@temptokena}}%
% AK: There are problems with using amsart's \markboth with babel
% http://www.tug.org/pipermail/macostex-archives/2004-December/011991.html
% and http://www.latex-project.org/cgi-bin/ltxbugs2html?pr=babel/3238
% Perhaps my amsart.cls (2.20) and babel (3.8d) installation are too old.
% Changed definition to using \markleft and \markright.
  \edef\@tempa{%
    \@nx\markleft{\the\toks4 \@nx\MakeUppercase{\the\toks@}}
    \@nx\markright{\the\@temptokena}}%
  \@tempa
  \endgroup
  \c@footnote\z@
  \@cleartopmattertags
}

\def\program#1{\def\@program{#1}}
\let\@program=\@empty

\def\university#1{\def\@university{#1}}
\let\@university=\@empty

\def\seminar#1{\def\@seminar{#1}}
\let\@seminar=\@empty

\def\submissionDate#1{\def\@submissionDate{#1}}
\let\@submissionDate=\@empty

\def\@maketitle{%
  \normalfont\normalsize
  \@adminfootnotes
  \ifx\@empty\@submissionDate
  \else
    \baselineskip12\p@
    \vtop{\raggedleft{\footnotesize\@submissionDate\@@par}%
      \global\dimen@i\prevdepth}\prevdepth\dimen@i
  \fi
  \ifx\@empty\@university
  \else
    \baselineskip12\p@
    \vtop{\centering{\footnotesize\itshape\@university\@@par}%
      \global\dimen@i\prevdepth}\prevdepth\dimen@i
  \fi
  \ifx\@empty\@seminar
  \else
    \baselineskip12\p@
    \vtop{\centering{\footnotesize\itshape\@seminar\@@par}%
      \global\dimen@i\prevdepth}\prevdepth\dimen@i
  \fi
  \@mkboth{\@nx\shortauthors}{\@nx\shorttitle}%
  \global\topskip42\p@\relax % 5.5pc   "   "   "     "     "
  \@settitle
  \ifx\@empty\authors \else \@setauthors \fi
  \ifx\@empty\@program
  \else
    \baselineskip12\p@
    \vtop{\centering{\footnotesize\itshape\@program\@@par}%
      \global\dimen@i\prevdepth}\prevdepth\dimen@i
  \fi
  \ifx\@empty\@dedicatory
  \else
    \baselineskip18\p@
    \vtop{\centering{\footnotesize\itshape\@dedicatory\@@par}%
      \global\dimen@i\prevdepth}\prevdepth\dimen@i
  \fi
  \@setabstract
  \normalsize
  \if@titlepage
    \newpage
  \else
    \dimen@34\p@ \advance\dimen@-\baselineskip
    \vskip\dimen@\relax
  \fi
} % end \@maketitle


% Redefine section, subsection, and paragraph
\def\section{\@startsection{section}{1}%
  \z@{1.5\linespacing\@plus.5\linespacing}{.5\linespacing}%
  {\normalfont\scshape\centering}}
\def\subsection{\@startsection{subsection}{2}%
  \z@{1\linespacing\@plus.3\linespacing}{.5\linespacing}%
  {\normalfont\itshape}}
\def\paragraph{\@startsection{paragraph}{4}%
  \z@{.5\linespacing\@plus.16\linespacing}{-\fontdimen2\font}%
  {\normalfont\itshape}}

% Formatting
\advance\topmargin by -1.2cm
%\advance\textheight by 1cm
\textheight647pt
\advance\evensidemargin by -1.1cm
\advance\oddsidemargin by -1.1cm
\advance\textwidth by 2.2cm
\parindent0pt
%\newif\ifdoublespaced\doublespacedtrue
\newif\ifdoublespaced\doublespacedfalse
\ifdoublespaced\renewcommand{\baselinestretch}{1.5}\else\fi
\renewcommand{\topfraction}{0.99}
\renewcommand{\bottomfraction}{0.99}
\renewcommand{\textfraction}{0.01}
\setlength\textfloatsep{6mm plus 4pt minus 4pt}
\allowdisplaybreaks
%\raggedbottom

